@@ -40,7 +40,7 @@ APPLET_NAME = 'firewall-applet'
 DATADIR = '/usr/share/' + DAEMON_NAME
 CONFIG_GLADE_NAME = CONFIG_NAME + '.glade'
 COPYRIGHT = '(C) 2010-2017 Red Hat, Inc.'
-VERSION = '1.3.3'
+VERSION = '1.3.4'
 AUTHORS = [
     "Thomas Woerner <twoerner@redhat.com>",
     "Jiri Popelka <jpopelka@redhat.com>",
@@ -113,8 +113,8 @@ COMMANDS = {
     "eb":           "/usr/sbin/ebtables",
     "eb-restore":   "/usr/sbin/ebtables-restore",
     "ipset":        "/usr/sbin/ipset",
-    "modprobe":     "/usr/sbin/modprobe",
-    "rmmod":        "/usr/sbin/rmmod",
+    "modprobe":     "/sbin/modprobe",
+    "rmmod":        "/sbin/rmmod",
 }
 
 LOG_DENIED_VALUES = [ "all", "unicast", "broadcast", "multicast", "off" ]
