@@ -171,7 +171,6 @@ class nftables(object):
         self.rich_rule_priority_counts = {}
         self.policy_priority_counts = {}
         self.zone_source_index_cache = {}
-        self.created_tables = {"inet": []}
 
         self.nftables = Nftables()
         self.nftables.set_echo_output(True)
@@ -393,6 +392,17 @@ class nftables(object):
         # Tables always exist in nftables
         return [table] if table else IPTABLES_TO_NFT_HOOK.keys()
 
+    def _build_delete_table_rules(self, table):
+        # To avoid nftables returning ENOENT we always add the table before
+        # deleting to guarantee it will exist.
+        #
+        # In the future, this add+delete should be replaced with "destroy", but
+        # that verb is too new to rely upon.
+        return [{"add": {"table": {"family": "inet",
+                                   "name": table}}},
+                {"delete": {"table": {"family": "inet",
+                                      "name": table}}}]
+
     def build_flush_rules(self):
         # Policy is stashed in a separate table that we're _not_ going to
         # flush. As such, we retain the policy rule handles and ref counts.
@@ -410,12 +420,7 @@ class nftables(object):
         self.policy_priority_counts = {}
         self.zone_source_index_cache = {}
 
-        rules = []
-        if TABLE_NAME in self.created_tables["inet"]:
-            rules.append({"delete": {"table": {"family": "inet",
-                                               "name": TABLE_NAME}}})
-            self.created_tables["inet"].remove(TABLE_NAME)
-        return rules
+        return self._build_delete_table_rules(TABLE_NAME)
 
     def _build_set_policy_rules_ct_rules(self, enable):
         add_del = { True: "add", False: "delete" }[enable]
@@ -438,7 +443,6 @@ class nftables(object):
         if policy == "PANIC":
             rules.append({"add": {"table": {"family": "inet",
                                             "name": TABLE_NAME_POLICY}}})
-            self.created_tables["inet"].append(TABLE_NAME_POLICY)
 
             # Use "raw" priority for panic mode. This occurs before
             # conntrack, mangle, nat, etc
@@ -453,7 +457,6 @@ class nftables(object):
         elif policy == "DROP":
             rules.append({"add": {"table": {"family": "inet",
                                             "name": TABLE_NAME_POLICY}}})
-            self.created_tables["inet"].append(TABLE_NAME_POLICY)
 
             # To drop everything except existing connections we use
             # "filter" because it occurs _after_ conntrack.
@@ -473,10 +476,7 @@ class nftables(object):
                 if policy_key in self.rule_to_handle:
                     rules.append(rule)
 
-            if TABLE_NAME_POLICY in self.created_tables["inet"]:
-                rules.append({"delete": {"table": {"family": "inet",
-                                                   "name": TABLE_NAME_POLICY}}})
-                self.created_tables["inet"].remove(TABLE_NAME_POLICY)
+            rules += self._build_delete_table_rules(TABLE_NAME_POLICY)
         else:
             raise FirewallError(UNKNOWN_ERROR, "not implemented")
 
@@ -496,7 +496,6 @@ class nftables(object):
         default_tables = []
         default_tables.append({"add": {"table": {"family": "inet",
                                                  "name": TABLE_NAME}}})
-        self.created_tables["inet"].append(TABLE_NAME)
         return default_tables
 
     def build_default_rules(self, log_denied="off"):
@@ -1724,9 +1723,9 @@ class nftables(object):
 
         if options:
             if "timeout" in options:
-                set_dict["timeout"] = options["timeout"]
+                set_dict["timeout"] = int(options["timeout"])
             if "maxelem" in options:
-                set_dict["size"] = options["maxelem"]
+                set_dict["size"] = int(options["maxelem"])
 
         return [{"add": {"set": set_dict}}]
 
@@ -1795,19 +1794,22 @@ class nftables(object):
                     fragment.append({"range": [port_str[:index], port_str[index+1:]]})
 
             elif format in ["ip", "net"]:
-                try:
-                    index = entry_tokens[i].index("/")
-                except ValueError:
-                    addr = entry_tokens[i]
-                    if "family" in obj.options and obj.options["family"] == "inet6":
-                        addr = normalizeIP6(addr)
-                    fragment.append(addr)
+                if '-' in entry_tokens[i]:
+                    fragment.append({"range": entry_tokens[i].split('-') })
                 else:
-                    addr = entry_tokens[i][:index]
-                    if "family" in obj.options and obj.options["family"] == "inet6":
-                        addr = normalizeIP6(addr)
-                    fragment.append({"prefix": {"addr": addr,
-                                                "len": int(entry_tokens[i][index+1:])}})
+                    try:
+                        index = entry_tokens[i].index("/")
+                    except ValueError:
+                        addr = entry_tokens[i]
+                        if "family" in obj.options and obj.options["family"] == "inet6":
+                            addr = normalizeIP6(addr)
+                        fragment.append(addr)
+                    else:
+                        addr = entry_tokens[i][:index]
+                        if "family" in obj.options and obj.options["family"] == "inet6":
+                            addr = normalizeIP6(addr)
+                        fragment.append({"prefix": {"addr": addr,
+                                                    "len": int(entry_tokens[i][index+1:])}})
             else:
                 fragment.append(entry_tokens[i])
         return [{"concat": fragment}] if len(type_format) > 1 else fragment
